@@ -4,6 +4,7 @@ from .Action import Action
 from .Image import Image
 from .Kernel import Kernel
 from .baseapi import BaseAPI
+from .SSHKey import SSHKey
 
 class Droplet(BaseAPI):
     def __init__(self, *args, **kwargs):
@@ -16,7 +17,7 @@ class Droplet(BaseAPI):
         self.region = []
         self.status = None
         self.image = None
-        self.size = None
+        self.size_slug = None
         self.locked = None
         self.created_at = None
         self.status = None
@@ -29,7 +30,7 @@ class Droplet(BaseAPI):
         self.ip_address = None
         self.private_ip_address = None
         self.ip_v6_address = None
-        self.ssh_keys = None
+        self.ssh_keys = []
         self.backups = None
         self.ipv6 = None
         self.private_networking = None
@@ -140,14 +141,14 @@ class Droplet(BaseAPI):
             params={'type': 'password_reset'}
         )
 
-    def resize(self, new_size):
+    def resize(self, new_size_slug):
         """
-            resize the droplet to a new size
+            resize the droplet to a new size slug.
         """
         return self.get_data(
             "droplets/%s/actions/" % self.id,
             type="POST",
-            params={"type": "resize", "size": new_size}
+            params={"type": "resize", "size": new_size_slug}
         )
 
     def take_snapshot(self, snapshot_name):
@@ -251,29 +252,56 @@ class Droplet(BaseAPI):
             params={'type' : 'change_kernel', 'kernel': kernel.id}
         )
 
-    def create(self, ssh_keys=None, backups=False, ipv6=False, private_networking=False, user_data=None):
+    def __get_ssh_keys_id(self):
+        """
+            Check and return a list of SSH key IDs according to DigitalOcean's
+            API. This method is usde to check and create a droplet with the
+            correct SSH keys.
+        """
+        ssh_keys_id = list()
+        for ssh_key in self.ssh_keys:
+            if type(ssh_key) in [int, long]:
+                ssh_keys_id.append( int(ssh_key) )
+
+            elif type(ssh_key) == SSHKey:
+                ssh_keys_id.append(ssh_key.id)
+
+            elif type(ssh_key) in [str, unicode]:
+                key = SSHKey()
+                key.token = self.token
+                results = key.load_by_pub_key(ssh_key)
+
+                if results == None:
+                    key.public_key = ssh_key
+                    key.name = "SSH Key %s" % self.name
+                    key.create()
+                else:
+                    key = results
+
+                ssh_keys_id.append(key.id)
+            else:
+                raise Exception("Droplet.ssh_keys should be a list of IDs or public keys")
+
+        return ssh_keys_id
+
+    def create(self, *args, **kwargs):
         """
             Create the droplet with object properties.
+
+            Note: Every argument and parameter given to this method will be
+            assigned to the object.
         """
+        for attr in kwargs.keys():
+            setattr(self,attr,kwargs[attr])
+
         data = {
                 "name": self.name,
-                "size": self.size,
+                "size": self.size_slug,
                 "image": self.image,
                 "region": self.region,
-                "ssh_keys[]": self.ssh_keys
+                "ssh_keys[]": self.__get_ssh_keys_id(),
             }
 
-        if user_data:
-            data["user_data"] = user_data
-
-        if ssh_keys:
-            if type(ssh_keys) in [int, long, str]:
-                data['ssh_keys[]']= str(ssh_keys)
-            elif type(ssh_keys) in [set, list, tuple, dict]:
-                data['ssh_keys[]'] = ','.join(str(x) for x in ssh_keys)
-            else:
-                raise Exception("ssh_key_ids should be an integer or long number, a string, a set, a list/tuple or a ditionary ")
-
         if self.backups:
             data['backups'] = True
 
