@@ -33,6 +33,21 @@ class SSHKey(BaseAPI):
             setattr(self,attr,ssh_key[attr])
         self.id = ssh_key['id']
 
+    def load_by_pub_key(self, public_key):
+        """
+            This method will laod a SSHKey object from DigitalOcean
+            from a public_key. This method will avoid problem like
+            uploading the same public_key twice.
+        """
+
+        data = self.get_data("account/keys/")
+        for jsoned in data['ssh_keys']:
+            if jsoned.get('public_key', "") == public_key:
+                self.id = jsoned['id']
+                self.load()
+                return self
+        return None
+
     def create(self):
         """
             Create the SSH Key
