@@ -1,18 +1,19 @@
 # -*- coding: utf-8 -*-
 import requests
-from urlparse import urljoin
+try:
+    from urlparse import urljoin
+except:
+    from urllib.parse import urljoin
 
 class BaseAPI(object):
     """
         Basic api class for
     """
     token = ""
-    call_response = None
     end_point = "https://api.digitalocean.com/v2/"
 
     def __init__(self, *args, **kwargs):
         self.token = ""
-        self.call_response = None
         self.end_point = "https://api.digitalocean.com/v2/"
 
         for attr in kwargs.keys():
